# Wordnet Skill

Use Wordnet to answer dictionary like questions

## About

Uses [Wordnet](https://wordnet.princeton.edu/) to provide information. 

checks language specific wordnets for `'en', 'als', 'arb', 'bg', 'cmn', 'da', 'el', 'fi', 'fr', 'he', 'hr', 'is', 'it', 'it-iwn', 'ja', 'ca', 'eu', 'gl', 'es', 'id', 'zsm', 'nl', 'nn', 'nb', 'pl', 'pt', 'ro', 'lt', 'sk', 'sl', 'sv', 'th'`

definitions are sometimes missing, when this happens the english text definition for the word will be machine translated

## Examples

* "what is the definition of ..."
* "what is the antonym of ..."

## Category
**Information**

## Tags
#Wordnet
#query
